@@ -236,14 +236,21 @@ class PGCli(object):
 @click.option('-U', '--user', envvar='PGUSER', help='User name to '
         'connect to the postgres database.')
 @click.option('-W', '--password', 'prompt_passwd', is_flag=True, default=False,
-              help='Force password prompt.')
+        help='Force password prompt.')
 @click.option('-w', '--no-password', 'never_prompt', is_flag=True,
-              default=False, help='Never issue a password prompt')
-@click.argument('database', default='', envvar='PGDATABASE')
-def cli(database, user, host, port, prompt_passwd, never_prompt):
-
+        default=False, help='Never prompt for password.')
+@click.option('-d', '--dbname', default='', envvar='PGDATABASE',
+        help='database name to connect to.')
+@click.argument('database', default=lambda: None, envvar='PGDATABASE', nargs=1)
+@click.argument('username', default=lambda: None, envvar='PGUSER', nargs=1)
+def cli(database, user, host, port, prompt_passwd, never_prompt, dbname,
+        username):
     pgcli = PGCli(prompt_passwd, never_prompt)
 
+    # Choose which ever one has a valid value.
+    database = database or dbname
+    user = username or user
+
     if '://' in database:
         pgcli.connect_uri(database)
     else:
@@ -276,6 +283,9 @@ def need_completion_refresh(sql):
         return False
 
 def is_mutating(status):
+    if not status:
+        return False
+    
     mutating = ['insert', 'update', 'delete', 'alter', 'create', 'drop']
     return status.split(None, 1)[0].lower() in mutating
 
