@@ -617,7 +617,7 @@ def describe_one_table_details(cur, schema_name, relation_name, oid, verbose):
 
                     #/* Everything after "TRIGGER" is echoed verbatim */
                     tgdef = row[1]
-                    triggerpos = indexdef.find(" TRIGGER ")
+                    triggerpos = tgdef.find(" TRIGGER ")
                     if triggerpos >= 0:
                         tgdef = triggerpos + 9;
 
@@ -762,7 +762,8 @@ def sql_name_pattern(pattern):
 def show_help(cur, arg, verbose):  # All the parameters are ignored.
     headers = ['Command', 'Description']
     result = []
-    for command, value in sorted(CASE_SENSITIVE_COMMANDS.iteritems()):
+
+    for command, value in sorted(CASE_SENSITIVE_COMMANDS.items()):
         if value[1]:
             result.append(value[1])
     return [(result, headers, None)]
